## 0.2.0a0 (2025-06-26)

### Feat

- add workflow api

### Refactor

- changing prompt api functionality

## 0.1.0 (2025-06-26)

### Feat

- add workflow api
- added initial working version of app

### Refactor

- changing prompt api functionality
